from .LEAP import LeapForCausalLM, LeapConfig, MultiheadLeap
from .fastformerLM.fastformer import FastformerForCausalLM, FastformerLMConfig